@@ -1,24 +1,11 @@
-/***********************************************************************
- * Copyright 2004  Max Howell <max.howell@methylblue.com>
- *           2007  Ian Monroe <ian@monroe.nu>
- * Copyright 2014 Lukáš Tinkl <lukas@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- ***********************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004 Max Howell <max.howell@methylblue.com>
+    SPDX-FileCopyrightText: 2007 Ian Monroe <ian@monroe.nu>
+    SPDX-FileCopyrightText: 2014 Lukáš Tinkl <lukas@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
+
 #include "codeine.h"
 #include "playerApplication.h"
 
@@ -44,11 +31,13 @@ int main( int argc, char **argv )
 
     KLocalizedString::setApplicationDomain("dragonplayer");
 
-    KAboutData aboutData( APP_NAME, i18n("Dragon Player"), QLatin1String(APP_VERSION),
+    KAboutData aboutData( QStringLiteral(APP_NAME),
+                          i18n("Dragon Player"),
+                          QStringLiteral(APP_VERSION),
                           i18n("A video player that has a usability focus"), KAboutLicense::GPL_V2,
                           i18n("Copyright 2006, Max Howell\nCopyright 2007, Ian Monroe"),
                           i18n("IRC:\nirc.freenode.net #dragonplayer\n\nFeedback:\nimonroe@kde.org"),
-                          "https://multimedia.kde.org" );
+                          QStringLiteral("https://commits.kde.org/dragon"));
     aboutData.setDesktopFileName(QStringLiteral("org.kde.dragonplayer"));
     aboutData.addCredit( QStringLiteral("David Edmundson"), i18n("Improvements and polish") );
     aboutData.addCredit( QStringLiteral("Matthias Kretz"), i18n("Creator of Phonon") );
@@ -64,8 +53,9 @@ int main( int argc, char **argv )
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 
-    parser.addOption(QCommandLineOption("play-dvd", i18n("Play DVD Video")));
-    parser.addPositionalArgument("url", i18n("Play 'URL'"), QStringLiteral("+[URL]"));
+    const QCommandLineOption playDvDOption(QStringLiteral("play-dvd"), i18n("Play DVD Video"));
+    parser.addOption(playDvDOption);
+    parser.addPositionalArgument(QStringLiteral("url"), i18n("Play 'URL'"), QStringLiteral("+[URL]"));
 
     parser.process(app);
     aboutData.processCommandLine(&parser);
@@ -83,7 +73,7 @@ int main( int argc, char **argv )
                                         QUrl::AssumeLocalFile));
     }
 
-    app.newInstance(parser.isSet("play-dvd"), urls);
+    app.newInstance(parser.isSet(playDvDOption), urls);
 
     return app.exec();
 }
